//客户端: ./create-api-client.js
//服务端：./create-api-server.js
// import { createAPI } from 'create-api'

const logRequests = !!process.env.DEBUG_API

import axios from 'axios'
import LRU from 'lru-cache'

function createAPI() {
    let api;
    if(process.__API__) {
        api = process.__API__
    } else {
        api = {
            onServer : true,
            cachedItems : LRU({
                max: 1000,
                maxAge: 1000 * 60 * 15 // 15分钟缓存
            }),
            cachedIds : {}
        }
    }
    return api;
}

const API = createAPI()
function fetch (url) {
    const s = Date.now()
    logRequests && console.log(`fetching ${url}...`)
    const cache = API.cachedItems
    if(cache && cache.has(url)) {
        logRequests && console.log(`cache hit for ${url}...(${Date.now() - s}ms)`)
        return Promise.resolve(cache.get(url))
    } else {
        return new Promise((resolve, reject) => {
            axios.request(url).then(res => {
                cache && cache.set(url, res)
                logRequests && console.log(`fetched ${url}...(${Date.now() - s}ms)`)
                resolve(res)
            })
        })
    }
}

export function getHomeInfo () {
    return fetch(`http://pb.duowan.com/s/api/home.json`)
}

export function getVideoLive () {
    return fetch(`http://open.douyucdn.cn/api/RoomApi/live/jdqs`)
}

export function getPlayerData (pname) {
    return fetch(`http://api-steam.duowan.com/api/v1/game/pubg/player/playerName/${pname}/`)
}